@@ -1,12 +1,11 @@
 package Net::PSYC::Datagram;
-#
-#
-#
-#
+
+use vars qw($VERSION);
+$VERSION = '0.4';
+
 use strict;
 use Carp;
 use IO::Socket::INET;
-use Data::Dumper;
 
 sub TRUST {
     return 1;
@@ -16,38 +15,39 @@ sub new {
     my $class = shift;
 
     my $addr = shift || undef;		# NOT 127.1
-    my $port = int(shift) || undef;	# also, NOT 4404
+    my $port = int(shift||0) || undef;	# also, NOT 4404
 
     my %a = (LocalPort => $port, Proto => 'udp');
     $a{LocalAddr} = $addr if $addr;
     my $socket = IO::Socket::INET->new(%a)
 	or (croak("UDP bind to $addr:$port says: $@") && return 0);
-    
     my $self = {
 	'SOCKET' => $socket,
 	'IP' => $socket->sockhost,
 	'PORT' => $port || $socket->sockport,
 	'TYPE' => 'd',
-	'I_BUFFER' => [],
+	'I_BUFFER' => '',
 	'O_BUFFER' => [],
 	'O_COUNT'  => 0,
+	'LF' => '',
     };
+    print STDERR "UDP bind to $self->{'IP'}:$self->{'PORT'} successful\n" if Net::PSYC::DEBUG;
     return bless $self, $class; 
 }
 
 #   send ( target, mc, data, vars ) 
 sub send {
     my $self = shift;
-    my ( $target, $mc, $data, $vars, $v ) = @_;
+    my ( $target, $data, $vars ) = @_;
 
-    push(@{$self->{'O_BUFFER'}}, [ [$target, $mc, $data, $vars, $v] ]);
+    push(@{$self->{'O_BUFFER'}}, [ [$target, $data, $vars ] ]);
 
     if (!$Net::PSYC::AUTOWATCH) { # got no eventing.. send the packet instantly
         return $self->write();
     } else {
         Net::PSYC::Event::revoke($self->{'SOCKET'});
     }
-    return 0;
+    return 1;
 }
 
 sub write () {
@@ -62,7 +62,7 @@ sub write () {
     
     $port ||= Net::PSYC::PSYC_PORT();
     
-    $packet->[2]->{'_target'} ||= $target;
+    $packet->[1]->{'_target'} ||= $target;
 
 # funny, but not what we want.. returns 0.0.0.0 for INADDR_ANY and even
 # when the ip is useful, the port may not - the other side should better
@@ -71,7 +71,7 @@ sub write () {
 #   $vars->{'_source'} |= "psyc://$self->{'IP'}:$self->{'PORT'}/";
 
     my $m = ".\n"; # empty packet!
-    $m .= Net::PSYC::makeMSG( @$packet );
+    $m .= Net::PSYC::makeMMP(reverse @$packet);
     
     ($port && $host) or croak('usage: obj->send( $target[, $method[, $data[, $vars[, $mvars]]]] )');
 
@@ -84,7 +84,7 @@ sub write () {
         croak($!);
         return $!;
     }
-    print STDERR "UDP[$self->{'HOST'}:$self->{'PORT'}] <= $packet->[2]->{'_source'}\: $$packet[0]\n"
+    print STDERR "UDP[$self->{'IP'}:$self->{'PORT'}] <= ".($packet->[1]->{'_source'}||Net::PSYC::UNL())."\n"
 	if Net::PSYC::DEBUG;
     if (!scalar(@{${$self->{'O_BUFFER'}}[$self->{'O_COUNT'}]})) {
         # all fragments of this packet sent
@@ -107,18 +107,29 @@ sub read () {
     $self->{'LAST_RECV'} = $self->{'SOCKET'}->recv($data, 8192); # READ socket
     
     return if (!$data); # connection lost !?
-    # gibt es nen 'richtigen' weg herauszufinden, ob die connection noch lebt?
-    # connected() und die ganzen anderen socket-funcs helfen einem da in
-    # den ekligen fllen nicht..
+    # gibt es nen 'richtigen' weg herauszufinden, ob der socket noch lebt?
 
     $self->{'I_BUFFER'} .= $data;
+    delete $self->{'LF'};
+    return 1;
 }
 
 #   returns _one_ mmp-packet .. or undef if the buffer is empty
 sub recv () {    
     my $self = shift;
-    if ($self->{'I_BUFFER'}) {
-	return Net::PSYC::MMPparse(\$$self{'I_BUFFER'});
+    print STDERR length($self->{'I_BUFFER'})."\n";
+    if (length($self->{'I_BUFFER'}) > 2) {
+	if ( $self->{'LF'} || $self->{'I_BUFFER'} =~ s/^\.(\r?\n)//g ) {
+	    
+	    $self->{'LF'} ||= $1;
+	    my ($vars, $data) = Net::PSYC::MMPparse(\$$self{'I_BUFFER'}, $self->{'LF'});
+	    return if (!defined $vars);
+	    $vars = $vars->{':'};
+	    return ($vars, $data);
+	}
+	# TODO : we need to provide a proper algorithm to clean up the
+	# in-buffer if we got corrupted packets in it. and we need to
+	# detect corrupted packets.. udp sucks noodles! ,-)
     }
     return;
 }
