@@ -1,5 +1,8 @@
 package Net::PSYC::Event::IO_Select;
 
+use vars qw($VERSION);
+$VERSION = '0.3';
+
 use Exporter;
 
 use strict;
@@ -110,10 +113,12 @@ sub startLoop {
 	    return 1 if ($cb{$_[0]}->{$_}[0] != 0);
 	}
     }
+    return 1;
 }
 
 sub stopLoop {
     $LOOP = 0;
+    return 1;
 }
 
 1;
